@@ -47,17 +47,10 @@ const startApp =
     await checkConfig(context);
     await performDatabaseIntegrityChecks(context);
 
-  context.timesync = await initTimesync({
-    models: context.models,
-    url: `${config.sync.host.trim().replace(/\/*$/, '')}/api/timesync`,
-  });
-
-  if (appType === APP_TYPES.API) {
-    context.syncConnection = new FacilitySyncConnection();
-  } else {
-    context.centralServer = new CentralServerConnection(context);
-    context.syncManager = new FacilitySyncManager(context);
-  }
+    context.timesync = await initTimesync({
+      models: context.models,
+      url: `${config.sync.host.trim().replace(/\/*$/, '')}/api/timesync`,
+    });
 
     if (appType === APP_TYPES.API) {
       context.syncConnection = new FacilitySyncConnection();
